# Bank Feeds API

Bank Feeds API enables your SMB users to set up bank feeds from accounts in your application to supported accounting platforms. 

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-bankfeeds
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatbankfeeds
from codatbankfeeds.models import operations, shared

s = codatbankfeeds.CodatBankFeeds(
    security=shared.Security(
        auth_header="Basic BASE_64_ENCODED(API_KEY)",
    ),
)

req = operations.CreateBankAccountMappingRequest(
    bank_feed_account_mapping=shared.BankFeedAccountMapping(
        feed_start_date='2022-10-23T00:00:00.000Z',
        source_account_id='provident',
        target_account_id='distinctio',
    ),
    company_id='8a210b68-6988-11ed-a1eb-0242ac120002',
    connection_id='2e9d2c44-f675-40ba-8049-353bfcb5e171',
)

res = s.bank_account_mapping.create(req)

if res.account_mapping_result is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [bank_account_mapping](docs/sdks/bankaccountmapping/README.md)

* [create](docs/sdks/bankaccountmapping/README.md#create) - Create bank feed bank account mapping
* [get](docs/sdks/bankaccountmapping/README.md#get) - List bank feed account mappings

### [bank_account_transactions](docs/sdks/bankaccounttransactions/README.md)

* [create](docs/sdks/bankaccounttransactions/README.md#create) - Create bank account transactions
* [get_create_model](docs/sdks/bankaccounttransactions/README.md#get_create_model) - Get create bank account transactions model
* [list](docs/sdks/bankaccounttransactions/README.md#list) - List bank account transactions

### [bank_feed_accounts](docs/sdks/bankfeedaccounts/README.md)

* [create](docs/sdks/bankfeedaccounts/README.md#create) - Create a bank feed bank account
* [list](docs/sdks/bankfeedaccounts/README.md#list) - List bank feed bank accounts
* [~~put_bank_feed~~](docs/sdks/bankfeedaccounts/README.md#put_bank_feed) - Create bank feed bank accounts :warning: **Deprecated**
* [~~update~~](docs/sdks/bankfeedaccounts/README.md#update) - Update bank feed bank account :warning: **Deprecated**

### [companies](docs/sdks/companies/README.md)

* [create](docs/sdks/companies/README.md#create) - Create company
* [delete](docs/sdks/companies/README.md#delete) - Delete a company
* [get](docs/sdks/companies/README.md#get) - Get company
* [list](docs/sdks/companies/README.md#list) - List companies
* [update](docs/sdks/companies/README.md#update) - Update company

### [connections](docs/sdks/connections/README.md)

* [create](docs/sdks/connections/README.md#create) - Create connection
* [delete](docs/sdks/connections/README.md#delete) - Delete connection
* [get](docs/sdks/connections/README.md#get) - Get connection
* [list](docs/sdks/connections/README.md#list) - List connections
* [proxy](docs/sdks/connections/README.md#proxy) - Proxy
* [unlink_connection](docs/sdks/connections/README.md#unlink_connection) - Unlink connection
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
